pub trait AggStateCacheFiller {
// Required methods
fn capacity(&self) -> Option<usize>;
fn append(&mut self, key: MemcmpEncoded, value: CacheValue);
fn finish(self: Box<Self>);
}Expand description
Trait that defines agg state cache syncing interface.
Required Methods
Sourcefn capacity(&self) -> Option<usize>
fn capacity(&self) -> Option<usize>
Get the capacity of the cache to be filled. None means unlimited.
Sourcefn append(&mut self, key: MemcmpEncoded, value: CacheValue)
fn append(&mut self, key: MemcmpEncoded, value: CacheValue)
Insert an entry to the cache without checking row count, capacity, key order, etc.
Just insert into the inner cache structure, e.g. BTreeMap.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".