dispatch_message_batch

Function dispatch_message_batch 

async fn dispatch_message_batch(
    inner: &mut DispatchExecutorInner,
    batch: MessageBatch,
) -> StreamResult<Option<Vec<Barrier>>>
Dispatches a message batch downstream and returns the barriers that should be yielded by the barrier stream.