fn time_scalar_to_timestamp(scalar: ScalarRefImpl<'_>) -> Option<Timestamp>Expand description
Extract the Timestamp the fill grid walks in from a time-column scalar; None if not a timestamp.
fn time_scalar_to_timestamp(scalar: ScalarRefImpl<'_>) -> Option<Timestamp>Extract the Timestamp the fill grid walks in from a time-column scalar; None if not a timestamp.