pub async fn load_table_at_least(
config: &IcebergConfig,
expected: Option<i64>,
) -> Result<Table>Expand description
Load the table, retrying until its snapshot set contains expected
pub async fn load_table_at_least(
config: &IcebergConfig,
expected: Option<i64>,
) -> Result<Table>Load the table, retrying until its snapshot set contains expected