ScalarImpl

Enum ScalarImpl 

pub enum ScalarImpl {
Show 21 variants Int16(i16), Int32(i32), Int64(i64), Int256(Int256), Float32(OrderedFloat<f32>), Float64(OrderedFloat<f64>), Utf8(Box<str>), Bool(bool), Decimal(Decimal), Interval(Interval), Date(Date), Time(Time), Timestamp(Timestamp), Timestamptz(Timestamptz), Jsonb(JsonbVal), Serial(Serial), Struct(StructValue), List(ListValue), Map(MapValue), Vector(VectorInner<Box<[OrderedFloat<f32>]>>), Bytea(Box<[u8]>),
}
ScalarImpl embeds all possible scalars in the evaluation framework.

Note: ScalarImpl doesn’t contain all information of its DataType, so sometimes they need to be used together. e.g., for Struct, we don’t have the field names in the value.

See for_all_variants for the definition.

Variants



Int16(i16)



Int32(i32)



Int64(i64)



Int256(Int256)



Float32(OrderedFloat<f32>)



Float64(OrderedFloat<f64>)



Utf8(Box<str>)



Bool(bool)



Decimal(Decimal)



Interval(Interval)



Date(Date)



Time(Time)



Timestamp(Timestamp)



Timestamptz(Timestamptz)



Jsonb(JsonbVal)



Serial(Serial)



Struct(StructValue)



List(ListValue)



Map(MapValue)



Vector(VectorInner<Box<[OrderedFloat<f32>]>>)



Bytea(Box<[u8]>)

Implementations

Source

impl ScalarImpl

pub fn get_ident(&self) -> &'static str

Source

impl ScalarImpl

pub fn successor(&self) -> Option<ScalarImpl>

Returns the successor of the current value if it exists.

See also Successor.

The function may return None when:

  1. The current value is the maximum value of the type.
  2. The successor value of the type is not well-defined.
Source

impl ScalarImpl

pub fn as_int16(&self) -> &i16

Panics

If the scalar is not of the expected type.

pub fn into_int16(self) -> i16

Panics

If the scalar is not of the expected type.

Source

impl ScalarImpl

pub fn as_int32(&self) -> &i32

Panics

If the scalar is not of the expected type.

pub fn into_int32(self) -> i32

Panics

If the scalar is not of the expected type.

Source

impl ScalarImpl

pub fn as_int64(&self) -> &i64

Panics

If the scalar is not of the expected type.

pub fn into_int64(self) -> i64

Panics

If the scalar is not of the expected type.

Source

impl ScalarImpl

pub fn as_int256(&self) -> &Int256

Panics

If the scalar is not of the expected type.

pub fn into_int256(self) -> Int256

Panics

If the scalar is not of the expected type.

Source

impl ScalarImpl

pub fn as_float32(&self) -> &OrderedFloat<f32>

Panics

If the scalar is not of the expected type.

pub fn into_float32(self) -> OrderedFloat<f32>

Panics

If the scalar is not of the expected type.

Source

impl ScalarImpl

pub fn as_float64(&self) -> &OrderedFloat<f64>

Panics

If the scalar is not of the expected type.

pub fn into_float64(self) -> OrderedFloat<f64>

Panics

If the scalar is not of the expected type.

Source

impl ScalarImpl

pub fn as_utf8(&self) -> &Box<str>

Panics

If the scalar is not of the expected type.

pub fn into_utf8(self) -> Box<str>

Panics

If the scalar is not of the expected type.

Source

impl ScalarImpl

pub fn as_bool(&self) -> &bool

Panics

If the scalar is not of the expected type.

pub fn into_bool(self) -> bool

Panics

If the scalar is not of the expected type.

Source

impl ScalarImpl

pub fn as_decimal(&self) -> &Decimal

Panics

If the scalar is not of the expected type.

pub fn into_decimal(self) -> Decimal

Panics

If the scalar is not of the expected type.

Source

impl ScalarImpl

pub fn as_interval(&self) -> &Interval

Panics

If the scalar is not of the expected type.

pub fn into_interval(self) -> Interval

Panics

If the scalar is not of the expected type.

Source

impl ScalarImpl

pub fn as_date(&self) -> &Date

Panics

If the scalar is not of the expected type.

pub fn into_date(self) -> Date

Panics

If the scalar is not of the expected type.

Source

impl ScalarImpl

pub fn as_time(&self) -> &Time

Panics

If the scalar is not of the expected type.

pub fn into_time(self) -> Time

Panics

If the scalar is not of the expected type.

Source

impl ScalarImpl

pub fn as_timestamp(&self) -> &Timestamp

Panics

If the scalar is not of the expected type.

pub fn into_timestamp(self) -> Timestamp

Panics

If the scalar is not of the expected type.

Source

impl ScalarImpl

pub fn as_timestamptz(&self) -> &Timestamptz

Panics

If the scalar is not of the expected type.

pub fn into_timestamptz(self) -> Timestamptz

Panics

If the scalar is not of the expected type.

Source

impl ScalarImpl

pub fn as_jsonb(&self) -> &JsonbVal

Panics

If the scalar is not of the expected type.

pub fn into_jsonb(self) -> JsonbVal

Panics

If the scalar is not of the expected type.

Source

impl ScalarImpl

pub fn as_serial(&self) -> &Serial

Panics

If the scalar is not of the expected type.

pub fn into_serial(self) -> Serial

Panics

If the scalar is not of the expected type.

Source

impl ScalarImpl

pub fn as_struct(&self) -> &StructValue

Panics

If the scalar is not of the expected type.

pub fn into_struct(self) -> StructValue

Panics

If the scalar is not of the expected type.

Source

impl ScalarImpl

pub fn as_list(&self) -> &ListValue

Panics

If the scalar is not of the expected type.

pub fn into_list(self) -> ListValue

Panics

If the scalar is not of the expected type.

Source

impl ScalarImpl

pub fn as_map(&self) -> &MapValue

Panics

If the scalar is not of the expected type.

pub fn into_map(self) -> MapValue

Panics

If the scalar is not of the expected type.

Source

impl ScalarImpl

pub fn as_vector(&self) -> &VectorInner<Box<[OrderedFloat<f32>]>>

Panics

If the scalar is not of the expected type.

pub fn into_vector(self) -> VectorInner<Box<[OrderedFloat<f32>]>>

Panics

If the scalar is not of the expected type.

Source

impl ScalarImpl

pub fn as_bytea(&self) -> &Box<[u8]>

Panics

If the scalar is not of the expected type.

pub fn into_bytea(self) -> Box<[u8]>

Panics

If the scalar is not of the expected type.

Source

impl ScalarImpl

pub fn from_binary( bytes: &Bytes, data_type: &DataType, ) -> Result<ScalarImpl, Box<dyn Error + Send + Sync>>

Creates a scalar from pgwire “BINARY” format.

The counterpart of to_binary::ToBinary.

pub fn from_text( s: &str, data_type: &DataType, ) -> Result<ScalarImpl, Box<dyn Error + Send + Sync>>

Creates a scalar from pgwire “TEXT” format.

The counterpart of ToText.

pub fn from_text_for_test( s: &str, data_type: &DataType, ) -> Result<ScalarImpl, Box<dyn Error + Send + Sync>>

Source

impl ScalarImpl

Source

impl ScalarImpl

pub fn serialize(&self, ser: &mut Serializer<impl BufMut>) -> Result<(), Error>

Serialize the scalar into the memcomparable format.

pub fn deserialize( ty: &DataType, de: &mut Deserializer<impl Buf>, ) -> Result<ScalarImpl, Error>

Deserialize the scalar from the memcomparable format.

pub fn as_integral(&self) -> i64