pub trait PositionDeleteHandler: Send + 'static {
// Required methods
fn write(&mut self, path: &str, pos: i64) -> StreamExecutorResult<()>;
fn flush<'life0, 'async_trait>(
&'life0 mut self,
) -> Pin<Box<dyn Future<Output = StreamExecutorResult<Option<SinkMetadata>>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
}Expand description
Trait abstracting position-delete file operations for testability.
Implementations are responsible for reading existing position deletes (V3 Puffin deletion vectors or V2 Parquet position-delete files), merging new delete positions, writing the resulting delete file, and returning the commit metadata for the current barrier.
Required Methods
fn write(&mut self, path: &str, pos: i64) -> StreamExecutorResult<()>
fn flush<'life0, 'async_trait>(
&'life0 mut self,
) -> Pin<Box<dyn Future<Output = StreamExecutorResult<Option<SinkMetadata>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".